@@ -87,7 +87,6 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         self.default_navigation_timeout: Optional[float] = None
         if "PLAYWRIGHT_DEFAULT_NAVIGATION_TIMEOUT" in crawler.settings:
             with suppress(TypeError, ValueError):
-                logger.info("Set default navigation timeout")
                 self.default_navigation_timeout = float(
                     crawler.settings.get("PLAYWRIGHT_DEFAULT_NAVIGATION_TIMEOUT")
                 )
@@ -256,7 +255,6 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         else:
             return result
         finally:
-            logger.info(f"[{request.url}] Start finally")
             try:
                 if page is not None and not page.is_closed():
                     logger.info(f"[{request.url}] Close page")
@@ -265,16 +263,13 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
                         logger.info(f"[{request.url}] Page closed")
                     except asyncio.TimeoutError:
                         if self.context_semaphores['default'].locked():
-                            logger.info(f"[{request.url}] Release semaphore")
                             self.context_semaphores['default'].release()
                         await self._plan_user_agent_rotation()
                     else:
                         if self.context_semaphores['default'].locked():
-                            logger.info(f"[{request.url}] Release semaphore")
                             self.context_semaphores['default'].release()
                 else:
                     if self.context_semaphores['default'].locked():
-                        logger.info(f"[{request.url}] Release semaphore")
                         self.context_semaphores['default'].release()
             except:
                 logger.error(f"[{request.url}] Error on page close")
@@ -282,7 +277,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
-        response = await page.goto(request.url, wait_until=self.page_load_until)
+        response = await page.goto(request.url, timeout=60000.0, wait_until=self.page_load_until)
 
         logger.info(f"[{request.url}] After goto")
         await self._apply_page_methods(page, request)
