@@ -1,4 +1,4 @@
-from scutils.method_timer import MethodTimer
+from bhfutils.scutils.method_timer import MethodTimer
 from time import sleep
 
 def timeout(sleep_time, wait_time, default, mul_value):
