@@ -1,12 +1,12 @@
 import argparse
-from scutils.settings_wrapper import SettingsWrapper
+from bhfutils.scutils.settings_wrapper import SettingsWrapper
 
 # set up arg parser
 parser = argparse.ArgumentParser(
     description='Example SettingsWrapper parser.\n')
 parser.add_argument('-s', '--settings', action='store', required=False,
                     help="The default settings file",
-                    default="settings_template.py")
+                    default="settings.py")
 parser.add_argument('-o', '--override-settings', action='store', required=False,
                     help="The override settings file",
                     default="localsettings.py")
